@@ -57,6 +57,7 @@ from .type_defs import (
     GetSchemaCreationStatusResponseTypeDef,
     GetTypeResponseTypeDef,
     HttpDataSourceConfigTypeDef,
+    LambdaAuthorizerConfigTypeDef,
     LambdaDataSourceConfigTypeDef,
     ListApiKeysResponseTypeDef,
     ListDataSourcesResponseTypeDef,
@@ -116,7 +117,7 @@ class Exceptions:
 
 class AppSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html)
     """
 
@@ -132,7 +133,7 @@ class AppSyncClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#can_paginate)
         """
 
@@ -149,7 +150,7 @@ class AppSyncClient(BaseClient):
         """
         Creates a cache for the GraphQL API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_api_cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_api_cache)
         """
 
@@ -160,7 +161,7 @@ class AppSyncClient(BaseClient):
         Creates a unique key that you can distribute to clients who are executing your
         API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_api_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_api_key)
         """
 
@@ -181,7 +182,7 @@ class AppSyncClient(BaseClient):
         """
         Creates a `DataSource` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_data_source)
         """
 
@@ -200,7 +201,7 @@ class AppSyncClient(BaseClient):
         """
         Creates a `Function` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_function)
         """
 
@@ -214,12 +215,13 @@ class AppSyncClient(BaseClient):
         openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
         tags: Dict[str, str] = None,
         additionalAuthenticationProviders: List["AdditionalAuthenticationProviderTypeDef"] = None,
-        xrayEnabled: bool = None
+        xrayEnabled: bool = None,
+        lambdaAuthorizerConfig: "LambdaAuthorizerConfigTypeDef" = None
     ) -> CreateGraphqlApiResponseTypeDef:
         """
         Creates a `GraphqlApi` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_graphql_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_graphql_api)
         """
 
@@ -240,7 +242,7 @@ class AppSyncClient(BaseClient):
         """
         Creates a `Resolver` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_resolver)
         """
 
@@ -250,7 +252,7 @@ class AppSyncClient(BaseClient):
         """
         Creates a `Type` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.create_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.create_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_type)
         """
 
@@ -258,7 +260,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes an `ApiCache` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_api_cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_api_cache)
         """
 
@@ -266,7 +268,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes an API key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_api_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_api_key)
         """
 
@@ -274,7 +276,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes a `DataSource` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_data_source)
         """
 
@@ -282,7 +284,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes a `Function` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_function)
         """
 
@@ -290,7 +292,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes a `GraphqlApi` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_graphql_api)
         """
 
@@ -298,7 +300,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes a `Resolver` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_resolver)
         """
 
@@ -306,7 +308,7 @@ class AppSyncClient(BaseClient):
         """
         Deletes a `Type` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.delete_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.delete_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_type)
         """
 
@@ -314,7 +316,7 @@ class AppSyncClient(BaseClient):
         """
         Flushes an `ApiCache` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.flush_api_cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.flush_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#flush_api_cache)
         """
 
@@ -328,7 +330,7 @@ class AppSyncClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#generate_presigned_url)
         """
 
@@ -336,7 +338,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves an `ApiCache` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_api_cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_api_cache)
         """
 
@@ -344,7 +346,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves a `DataSource` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_data_source)
         """
 
@@ -352,7 +354,7 @@ class AppSyncClient(BaseClient):
         """
         Get a `Function` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_function)
         """
 
@@ -360,7 +362,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves a `GraphqlApi` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_graphql_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_graphql_api)
         """
 
@@ -370,7 +372,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves the introspection schema for a GraphQL API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_introspection_schema)
         """
 
@@ -380,7 +382,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves a `Resolver` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_resolver)
         """
 
@@ -388,7 +390,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves the current status of a schema creation operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_schema_creation_status)
         """
 
@@ -398,7 +400,7 @@ class AppSyncClient(BaseClient):
         """
         Retrieves a `Type` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.get_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.get_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_type)
         """
 
@@ -408,7 +410,7 @@ class AppSyncClient(BaseClient):
         """
         Lists the API keys for a given API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_api_keys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_api_keys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_api_keys)
         """
 
@@ -418,7 +420,7 @@ class AppSyncClient(BaseClient):
         """
         Lists the data sources for a given API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_data_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_data_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_data_sources)
         """
 
@@ -428,7 +430,7 @@ class AppSyncClient(BaseClient):
         """
         List multiple functions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_functions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_functions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_functions)
         """
 
@@ -438,7 +440,7 @@ class AppSyncClient(BaseClient):
         """
         Lists your GraphQL APIs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_graphql_apis)
         """
 
@@ -448,7 +450,7 @@ class AppSyncClient(BaseClient):
         """
         Lists the resolvers for a given API and type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_resolvers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_resolvers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_resolvers)
         """
 
@@ -458,7 +460,7 @@ class AppSyncClient(BaseClient):
         """
         List the resolvers that are associated with a specific function.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_resolvers_by_function)
         """
 
@@ -466,7 +468,7 @@ class AppSyncClient(BaseClient):
         """
         Lists the tags for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_tags_for_resource)
         """
 
@@ -481,7 +483,7 @@ class AppSyncClient(BaseClient):
         """
         Lists the types for a given API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.list_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.list_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_types)
         """
 
@@ -491,7 +493,7 @@ class AppSyncClient(BaseClient):
         """
         Adds a new schema to your GraphQL API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.start_schema_creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.start_schema_creation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#start_schema_creation)
         """
 
@@ -499,7 +501,7 @@ class AppSyncClient(BaseClient):
         """
         Tags a resource with user-supplied tags.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#tag_resource)
         """
 
@@ -507,7 +509,7 @@ class AppSyncClient(BaseClient):
         """
         Untags a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#untag_resource)
         """
 
@@ -522,7 +524,7 @@ class AppSyncClient(BaseClient):
         """
         Updates the cache for the GraphQL API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_api_cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_api_cache)
         """
 
@@ -532,7 +534,7 @@ class AppSyncClient(BaseClient):
         """
         Updates an API key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_api_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_api_key)
         """
 
@@ -553,7 +555,7 @@ class AppSyncClient(BaseClient):
         """
         Updates a `DataSource` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_data_source)
         """
 
@@ -573,7 +575,7 @@ class AppSyncClient(BaseClient):
         """
         Updates a `Function` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_function)
         """
 
@@ -587,12 +589,13 @@ class AppSyncClient(BaseClient):
         userPoolConfig: "UserPoolConfigTypeDef" = None,
         openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
         additionalAuthenticationProviders: List["AdditionalAuthenticationProviderTypeDef"] = None,
-        xrayEnabled: bool = None
+        xrayEnabled: bool = None,
+        lambdaAuthorizerConfig: "LambdaAuthorizerConfigTypeDef" = None
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
         Updates a `GraphqlApi` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_graphql_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_graphql_api)
         """
 
@@ -613,7 +616,7 @@ class AppSyncClient(BaseClient):
         """
         Updates a `Resolver` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_resolver)
         """
 
@@ -623,14 +626,14 @@ class AppSyncClient(BaseClient):
         """
         Updates a `Type` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Client.update_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Client.update_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_type)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_api_keys"]) -> ListApiKeysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listapikeyspaginator)
         """
 
@@ -639,14 +642,14 @@ class AppSyncClient(BaseClient):
         self, operation_name: Literal["list_data_sources"]
     ) -> ListDataSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listdatasourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_functions"]) -> ListFunctionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listfunctionspaginator)
         """
 
@@ -655,14 +658,14 @@ class AppSyncClient(BaseClient):
         self, operation_name: Literal["list_graphql_apis"]
     ) -> ListGraphqlApisPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listgraphqlapispaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resolvers"]) -> ListResolversPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolverspaginator)
         """
 
@@ -671,13 +674,13 @@ class AppSyncClient(BaseClient):
         self, operation_name: Literal["list_resolvers_by_function"]
     ) -> ListResolversByFunctionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolversbyfunctionpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_types"]) -> ListTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.10/reference/services/appsync.html#AppSync.Paginator.ListTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/appsync.html#AppSync.Paginator.ListTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listtypespaginator)
         """
